summaryrefslogtreecommitdiffstats
path: root/os-plugins/plugins/vmgrid/files/run-vmgrid.sh
diff options
context:
space:
mode:
Diffstat (limited to 'os-plugins/plugins/vmgrid/files/run-vmgrid.sh')
-rw-r--r--os-plugins/plugins/vmgrid/files/run-vmgrid.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/os-plugins/plugins/vmgrid/files/run-vmgrid.sh b/os-plugins/plugins/vmgrid/files/run-vmgrid.sh
index 5e64b4cd..1501749e 100644
--- a/os-plugins/plugins/vmgrid/files/run-vmgrid.sh
+++ b/os-plugins/plugins/vmgrid/files/run-vmgrid.sh
@@ -53,19 +53,19 @@ writelog () {
### Get XML file and dir
################################################################################
# check if forcemem or graphical mode set
headless=1
while [ $# -gt 0 ]; do
case "$1" in
-h|--help)
- echo -e "Usage: run-vmgrid.sh [-g] [--forcemem <memorysize in MB>] \c"
+ echo -e "Usage: run-vmgrid.sh [-g] [--mem <memorysize in MB>] \c"
echo -e "[/path/]filename[.xml]"
exit
;;
-g)
headless=0
;;
- --forcemem)
+ --mem)
# get a result which can be divided through 4
forcemem=$2
echo $2 | grep -q '[1-9][0-9]\{2,3\}$' && forcemem=$(expr $2 / 4 \* 4)
@@ -53,19 +53,19 @@ writelog () {
### Get XML file and dir
################################################################################
-# check if forcemem or graphical mode set
+# check if mem or graphical mode set
headless=1
while [ $# -gt 0 ]; do